#include <LiquidCrystal_PCF8574.h>
#include <Wire.h>

LiquidCrystal_PCF8574 lcd(0x27); // set the LCD address to 0x27 for a 16 chars and 2 line display

int show = -1;

/// print binary all digits
void printBinary(uint8_t val, uint8_t lcdout) {
	for (uint8_t i = 0; i < 8; i ++) {
		uint8_t b = val > 0x7F;
		if (lcdout) {
			lcd.print(b);
		} else {
			Serial.print(b);
		}
		val = val << 1;
	}
}

/// wait with polling buttons
void wait_button(int waittime) {
	do {
		uint8_t button = lcd.getButton();
		lcd.setCursor(0, 2);
		lcd.print("Buttons:");
		lcd.setCursor(0, 3);
		printBinary(button, 1);
// 		printBinary(button, 0);
// 		Serial.println();
		if (!lcd.get1Button(7)) {	// single button / input
			lcd.setCursor(9, 3);
			lcd.print("8");
		}
		waittime --;
	} while (waittime > 0);
}

/// setup routine
void setup() {
	int error;

	Serial.begin(115200);
	Serial.println("LCD-I2C Test");

	// wait on Serial to be available on Leonardo
	while (!Serial)
	;

	Serial.println("Check for LCD");

	// See http://playground.arduino.cc/Main/I2cScanner how to test for a I2C device.
	Wire.begin();
	Wire.beginTransmission(0x27);
	error = Wire.endTransmission();

	if (error == 0) {
		Serial.println("LCD found.");
		show = 0;
		lcd.begin(10, 4); // initialize the lcd
	} else {
		Serial.println("LCD not found.");
		Serial.print("Error: ");
		Serial.print(error);
	} // if

} // setup()


/// main loop
void loop() {
	if (show == 0) {
		lcd.home();
		lcd.clear();
		lcd.print("Hello LCD");
		Serial.println("Hello LCD");
	} else if (show == 1) {
		lcd.clear();
		lcd.print("Cursor");
		lcd.setCursor(0, 1);
		lcd.print("On");
		Serial.println("Cursor On");
		lcd.cursor();
	} else if (show == 2) {
		lcd.clear();
		lcd.print("Cursor");
		lcd.setCursor(0, 1);
		lcd.print("Blink");
		Serial.println("Cursor Blink");
		lcd.blink();
	} else if (show == 3) {
		lcd.clear();
		lcd.print("Cursor");
		lcd.setCursor(0, 1);
		lcd.print("Off");
		Serial.println("Cursor OFF");
		lcd.noBlink();
		lcd.noCursor();
	} else if (show == 4) {
		lcd.clear();
		lcd.print("Display");
		lcd.setCursor(0, 1);
		lcd.print("Off");
		Serial.println("Display Off");
		lcd.noDisplay();
	} else if (show == 5) {
		lcd.clear();
		lcd.print("Display On");
		lcd.setCursor(0, 1);
		lcd.print("On again");
		Serial.println("Display On");
		lcd.display();
	} else if (show == 7) {
		lcd.clear();
		lcd.setCursor(0, 0);
		lcd.print("*** first");
		Serial.println("*** first line.");
		lcd.setCursor(0, 1);
		lcd.print("*** second");
		Serial.println("*** second line.");
	} else if (show == 8) {
		lcd.scrollDisplayLeft();
		Serial.println("Scroll left");
	} else if (show == 9) {
		lcd.scrollDisplayLeft();
	} else if (show == 10) {
		lcd.scrollDisplayRight();
		Serial.println("Scroll right");
	}

	wait_button(100);
	show = (show + 1) % 11;
} // loop()
